==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/gui/model/NavigationTableColumnModel.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.model;

import javax.swing.table.DefaultTableColumnModel;
import javax.swing.table.TableColumn;

import net.sourceforge.atunes.kernel.controllers.navigation.NavigationController;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationControllerViews;

/**
 * The Class NavigationTableColumnModel.
 */
public class NavigationTableColumnModel extends DefaultTableColumnModel {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1071222881574684439L;

	/** The controller. */
	private NavigationController controller;

	/**
	 * Instantiates a new navigation table column model.
	 * 
	 * @param controller
	 *            the controller
	 */
	public NavigationTableColumnModel(NavigationController controller) {
		this.controller = controller;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.DefaultTableColumnModel#addColumn(javax.swing.table.TableColumn)
	 */
	@Override
	public void addColumn(TableColumn aColumn) {
		super.addColumn(aColumn);

		// First column shows favorite icon
		if (aColumn.getModelIndex() == 0)
			aColumn.setMaxWidth(20);

		if (controller.getState().getNavigationView() != NavigationControllerViews.PODCAST_FEED_VIEW) {
			if (aColumn.getModelIndex() == 2)
				aColumn.setMaxWidth(50);
		} else {
			if (aColumn.getModelIndex() == 2)
				aColumn.setMaxWidth(18);
			else if (aColumn.getModelIndex() == 1) {
				aColumn.setMaxWidth(18);
			} else if (aColumn.getModelIndex() == 4) {
				aColumn.setMaxWidth(50);
			}
		}
	}

}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/gui/model/NavigationTableColumnModel.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.model;

import javax.swing.table.DefaultTableColumnModel;
import javax.swing.table.TableColumn;

import net.sourceforge.atunes.kernel.controllers.navigation.NavigationController;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationControllerViews;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationControllerState.ViewMode;

/**
 * The Class NavigationTableColumnModel.
 */
public class NavigationTableColumnModel extends DefaultTableColumnModel {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1071222881574684439L;

	/** The controller. */
	private NavigationController controller;

	/**
	 * Instantiates a new navigation table column model.
	 * 
	 * @param controller
	 *            the controller
	 */
	public NavigationTableColumnModel(NavigationController controller) {
		this.controller = controller;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * javax.swing.table.DefaultTableColumnModel#addColumn(javax.swing.table
	 * .TableColumn)
	 */
	@Override
	public void addColumn(TableColumn aColumn) {
		super.addColumn(aColumn);

		// First column shows favorite icon
		if (aColumn.getModelIndex() == 0) {
			aColumn.setMaxWidth(20);
		}

		if (controller.getState().getNavigationView() == NavigationControllerViews.PODCAST_FEED_VIEW) {
			if (aColumn.getModelIndex() == 2) {
				aColumn.setMaxWidth(18);
			} else if (aColumn.getModelIndex() == 1) {
				aColumn.setMaxWidth(18);
			} else if (aColumn.getModelIndex() == 4) {
				aColumn.setMaxWidth(50);
			}
		} else if (controller.getState().getNavigationView() == NavigationControllerViews.REPOSITORY_VIEW) {
			if (controller.getState().getViewMode() != ViewMode.FOLDER) {
				if (aColumn.getModelIndex() == 1) {
					aColumn.setMaxWidth(18);
				} else if (aColumn.getModelIndex() == 3) {
					aColumn.setMaxWidth(50);
				}
			} else {
				if (aColumn.getModelIndex() == 2) {
					aColumn.setMaxWidth(50);
				}
			}
		} else {
			if (aColumn.getModelIndex() == 2) {
				aColumn.setMaxWidth(50);
			}
		}
	}

}
